@@ -1,9 +1,11 @@
 package App::FileDeleteUtils;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-02'; # DATE
+our $DATE = '2023-11-20'; # DATE
 our $DIST = 'App-FileRemoveUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 1;
 # ABSTRACT: Utilities related to removing/deleting files
@@ -20,7 +22,7 @@ App::FileDeleteUtils - Utilities related to removing/deleting files
 
 =head1 VERSION
 
-This document describes version 0.006 of App::FileDeleteUtils (from Perl distribution App-FileRemoveUtils), released on 2021-08-02.
+This document describes version 0.007 of App::FileDeleteUtils (from Perl distribution App-FileRemoveUtils), released on 2023-11-20.
 
 =head1 DESCRIPTION
 
@@ -34,6 +36,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-FileRe
 
 Source repository is at L<https://github.com/perlancar/perl-App-FileRemoveUtils>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FileRemoveUtils>
@@ -42,15 +73,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
