@@ -1,16 +1,17 @@
 package App::FileRemoveUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-02'; # DATE
-our $DIST = 'App-FileRemoveUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 use Log::ger;
 
 use Exporter 'import';
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-11-20'; # DATE
+our $DIST = 'App-FileRemoveUtils'; # DIST
+our $VERSION = '0.007'; # VERSION
+
 our @EXPORT_OK = qw(delete_all_empty_files delete_all_empty_dirs);
 
 our %SPEC;
@@ -55,7 +56,7 @@ $SPEC{list_all_empty_dirs} = {
 };
 sub list_all_empty_dirs {
     require File::Find;
-    require File::MoreUtil;
+    require File::Util::Test;
 
     my $include_would_be_empty = $_[0] // 1;
 
@@ -65,9 +66,9 @@ sub list_all_empty_dirs {
             return if $_ eq '.' || $_ eq '..';
             return if -l $_;
             return unless -d _;
-            return if File::MoreUtil::dir_has_non_subdirs($_);
+            return if File::Util::Test::dir_has_non_subdirs($_);
             my $path = "$File::Find::dir/$_";
-            $dirs{$path} = { map {$_=>1} File::MoreUtil::get_dir_entries($_) };
+            $dirs{$path} = { map {$_=>1} File::Util::Test::get_dir_entries($_) };
         },
         '.'
     );
@@ -165,7 +166,7 @@ sub delete_all_empty_dirs {
         if ($args{-dry_run}) {
             log_info "[DRY-RUN] Deleting %s ...", $dir;
         } else {
-            if (File::MoreUtil::dir_empty($dir)) {
+            if (File::Util::Test::dir_empty($dir)) {
                 log_info "Deleting %s ...", $dir;
                 rmdir $dir or do {
                     log_error "Failed deleting %s: %s", $dir, $!;
@@ -192,7 +193,7 @@ App::FileRemoveUtils - Utilities related to removing/deleting files
 
 =head1 VERSION
 
-This document describes version 0.006 of App::FileRemoveUtils (from Perl distribution App-FileRemoveUtils), released on 2021-08-02.
+This document describes version 0.007 of App::FileRemoveUtils (from Perl distribution App-FileRemoveUtils), released on 2023-11-20.
 
 =head1 DESCRIPTION
 
@@ -336,14 +337,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-FileRe
 
 Source repository is at L<https://github.com/perlancar/perl-App-FileRemoveUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FileRemoveUtils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<rmhere> from L<App::rmhere>
@@ -355,11 +348,37 @@ L<App::FileRenameUtilities>.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
+This software is copyright (c) 2023 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-FileRemoveUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
